jank.build.cmake


cmakeclj

(cmake {:keys [src-dir build-dir] :as input}
       &
       {:keys [defines target] :or {target "install"}})

Run the cmake tool in the src-dir, building to the intermediate build-dir, and installing artifacts into the out-dir.

No jank-build directives are output, so make sure to specify the correct link/include directories, link libraries, etc. yourself.

Run the `cmake` tool in the src-dir, building to the intermediate build-dir,
and installing artifacts into the out-dir.

No jank-build directives are output, so make sure to specify the correct
link/include directories, link libraries, etc. yourself.
raw docstring

default-definesclj

(default-defines {:keys [out-dir optimization-level static?]
                  :or {optimization-level 0}})

install-rpathclj

(install-rpath)

cljdoc builds & hosts documentation for Clojure/Script libraries