jank.build.pkg-config


brew-pkg-config-pathclj

(brew-pkg-config-path build-input pkg)

has-static-lib?clj

(has-static-lib? lib link-dirs)

parse-prefixedclj

(parse-prefixed prefix s)

pkg-configclj

(pkg-config build-input pc-name)

Call the pkg-config tool and parse link directories, include directories, and link libraries.

jank-build directives will automatically be output for these values.

Call the `pkg-config` tool and parse link directories, include directories,
and link libraries.

jank-build directives will automatically be output for these values.
raw docstring

pkg-config-pathclj

(pkg-config-path & paths)

Rebuild the PKG_CONFIG_PATH string with additional paths prepended. nil entries are ignored.

Rebuild the PKG_CONFIG_PATH string with additional paths prepended. nil
entries are ignored.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries