jank.build.util


defineclj

(define k)
(define k v)

include-dirclj

(include-dir dir)

Add a jank include-dir directive (a -I flag). If a relative path is given then it is assumed to be relative to the build output directory.

Add a jank include-dir directive (a -I flag). If a relative path is given
then it is assumed to be relative to the build output directory.
raw docstring

(link-dir dir)

Add a jank link-dir directive (a -L flag). If a relative path is given then it is assumed to be relative to the build output directory.

Add a jank link-dir directive (a -L flag). If a relative path is given then
it is assumed to be relative to the build output directory.
raw docstring

(link-framework framework)

(link-library lib)

(link-static-library lib)

linux?clj

(linux?)

mac?clj

(mac?)

os-nameclj


rerun-if-changedclj

(rerun-if-changed path)

rerun-if-env-changedclj

(rerun-if-env-changed k)

windows?clj

(windows?)

cljdoc builds & hosts documentation for Clojure/Script libraries