(cmake {:keys [src-dir build-dir] :as input}
&
{:keys [defines target] :or {target "install"}})Run the cmake tool in the src-dir, building to the intermediate build-dir,
and installing artifacts into the out-dir.
No jank-build directives are output, so make sure to specify the correct link/include directories, link libraries, etc. yourself.
Run the `cmake` tool in the src-dir, building to the intermediate build-dir, and installing artifacts into the out-dir. No jank-build directives are output, so make sure to specify the correct link/include directories, link libraries, etc. yourself.
(default-defines {:keys [out-dir optimization-level static?]
:or {optimization-level 0}})(install-rpath)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |