(brew-pkg-config-path build-input pkg)(has-static-lib? lib link-dirs)(parse-prefixed prefix s)(pkg-config build-input pc-name)Call the pkg-config tool and parse link directories, include directories,
and link libraries.
jank-build directives will automatically be output for these values.
Call the `pkg-config` tool and parse link directories, include directories, and link libraries. jank-build directives will automatically be output for these values.
(pkg-config-path & paths)Rebuild the PKG_CONFIG_PATH string with additional paths prepended. nil entries are ignored.
Rebuild the PKG_CONFIG_PATH string with additional paths prepended. nil entries are ignored.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |