(define k)(define k v)(include-dir dir)Add a jank include-dir directive (a -I flag). If a relative path is given then it is assumed to be relative to the build output directory.
Add a jank include-dir directive (a -I flag). If a relative path is given then it is assumed to be relative to the build output directory.
(link-dir dir)Add a jank link-dir directive (a -L flag). If a relative path is given then it is assumed to be relative to the build output directory.
Add a jank link-dir directive (a -L flag). If a relative path is given then it is assumed to be relative to the build output directory.
(link-framework framework)(link-library lib)(link-static-library lib)(linux?)(mac?)(rerun-if-changed path)(rerun-if-env-changed k)(windows?)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |